@@ -1,6 +1,9 @@
 package Catalyst::Action::RenderView;
 
-our $VERSION='0.03';
+use strict;
+use warnings;
+
+our $VERSION = '0.05';
 
 use base 'Catalyst::Action';
 
@@ -9,11 +12,6 @@ sub execute {
     my ($controller, $c ) = @_;
     $self->NEXT::execute( @_ );
     if ($c->debug && $c->req->params->{dump_info}) {
-	foreach my $item (keys %{$c->stash}) {
-	    undef $item->{result_source} 
-	    if $item->isa('DBIx::Class::ResultSet') ||
-	    if $item->isa('DBIx::Class::Row');
-	}
 	die "forced debug" 
     }
     if(! $c->response->content_type ) {
@@ -46,17 +44,24 @@ response body. It also allows you to pass C<dump_info=1> to the url in
 order to force a debug screen, while in debug mode.
 
 If you have more than one view, you can specify which one to use with
-the C<default_view> config setting (see L<Catalyst/"$c->view($name)">.)
+the C<default_view> config setting (see L<Catalyst>'s C<$c->view($name)>
+method).
 
 =head1 METHODS
 
-=over 4
-
-=item end
+=head2 end
 
 The default C<end> action. You can override this as required in your
 application class; normal inheritance applies.
 
+=head1 INTERNAL METHODS
+
+=head2 execute
+
+Dispatches control to superclasses, then forwards to the default View.
+
+See L<Catalyst::Action/METHODS/action>.
+
 =head1 EXTENDING
 
 To add something to an C<end> action that is called before rendering,
@@ -78,8 +83,6 @@ you can set it up like this:
       # do stuff here
     }
 
-=back
-
 =head1 AUTHOR
 
 Marcus Ramberg <marcus@thefeed.no>
